==> demoniac-0.3.tar.gz: demoniac-0.3/libfx/dlg.h <==
/*
 * Calodox Demoniac
 * Copyright (C) 2001 Julien Pilet
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *  
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

/*
 * Dialog class for demoniac
 * leto@calodox.org, 14.9.2001
 */

#ifndef _DLG_H_
#define _DLG_H_

#include "gtk/gtk.h"

class Dlg {
protected:
	// is the dialog visible ?
	bool visible;

	// pointer to the gtk window
	GtkWidget *window;

public:
	// constructor
	Dlg() : visible(false), window(0) { }

	// destructor
	virtual ~Dlg();

	// build the dialog
	virtual void build() = 0;

	// make sure the dialog is shown
	virtual void show();

	// make sure the dialog is hidden
	virtual void hide();

	// callback for gtk
	static gint cbDeleteWindow(GtkWidget *window, GdkEvent *event,  Dlg *dlg);

	// if the dialog is shown: hide it.
	// if it's hidden: show it.
	virtual void switchVisibility();

	// get the name of the dialog
	virtual const char *getName() = 0;

	// returns true if the name has been changed,
	// false otherwise. The default methode just returns false.
	virtual bool setName(const char *name);
};

#endif

==> demoniac-0.4.tar.gz: demoniac-0.4/libfx/dlg.h <==
/*
 * Calodox Demoniac
 * Copyright (C) 2001 Julien Pilet
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *  
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

/*
 * Dialog class for demoniac
 * leto@calodox.org, 14.9.2001
 */

#ifndef _DLG_H_
#define _DLG_H_

#include "gtk/gtk.h"

class Dlg {
protected:
	// is the dialog visible ?
	bool visible;

	// pointer to the gtk window
	GtkWidget *window;

public:
	// constructor
	Dlg() : visible(false), window(0) { }

	// destructor
	virtual ~Dlg();

	// build the dialog
	virtual void build() = 0;

	// make sure the dialog is shown
	virtual void show();

	// make sure the dialog is hidden
	virtual void hide();

	// callback for gtk
	static gint cbDeleteWindow(GtkWidget *window, GdkEvent *event,  Dlg *dlg);
	static gint cbHide(GtkWidget *window, Dlg *dlg);

	// if the dialog is shown: hide it.
	// if it's hidden: show it.
	virtual void switchVisibility();

	// get the name of the dialog
	virtual const char *getName() = 0;

	// returns true if the name has been changed,
	// false otherwise. The default method just returns false.
	virtual bool setName(const char *name);
};

#endif
